Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_app.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_app.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_app.py	(revision 7811)
@@ -22,7 +22,7 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.app import University
-from waeup.sirp.interfaces import IUniversity
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.interfaces import IUniversity
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 class UniversityTests(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_authentication.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_authentication.py	(revision 7811)
@@ -22,7 +22,7 @@
 from zope.pluggableauth.interfaces import IAuthenticatorPlugin
 from zope.securitypolicy.interfaces import IPrincipalRoleManager
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
-from waeup.sirp.authentication import (
-    UserAuthenticatorPlugin, Account, SIRPPrincipalInfo,
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.authentication import (
+    UserAuthenticatorPlugin, Account, KOFAPrincipalInfo,
     get_principal_role_manager)
 
@@ -64,5 +64,5 @@
         result2 = plugin.authenticateCredentials(
             dict(login='bob', password='nonsense'))
-        self.assertTrue(isinstance(result1, SIRPPrincipalInfo))
+        self.assertTrue(isinstance(result1, KOFAPrincipalInfo))
         self.assertTrue(result2 is None)
         return
@@ -73,5 +73,5 @@
         result1 = plugin.principalInfo('bob')
         result2 = plugin.principalInfo('manfred')
-        self.assertTrue(isinstance(result1, SIRPPrincipalInfo))
+        self.assertTrue(isinstance(result1, KOFAPrincipalInfo))
         self.assertTrue(result2 is None)
         return
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_configuration.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_configuration.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_configuration.py	(revision 7811)
@@ -20,8 +20,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import verify
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.configuration import (
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.configuration import (
     ConfigurationContainer, SessionConfiguration, SessionConfigurationFactory)
-from waeup.sirp.interfaces import(
+from waeup.kofa.interfaces import(
     IConfigurationContainer, ISessionConfiguration, ISessionConfigurationAdd)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_imagestorage.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_imagestorage.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_imagestorage.py	(revision 7811)
@@ -27,10 +27,10 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.imagestorage import (
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.imagestorage import (
     FileStoreNameChooser, ExtFileStore, DefaultFileStoreHandler,
     DefaultStorage)
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IFileStoreNameChooser, IExtFileStore, IFileStoreHandler,)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_interfaces.py	(revision 7811)
@@ -20,6 +20,6 @@
 import grok
 import unittest
-from waeup.sirp.interfaces import DuplicationError, RoleSource
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.interfaces import DuplicationError, RoleSource
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 class DuplicationErrorTests(unittest.TestCase):
@@ -48,10 +48,10 @@
         # Register a role not visible to waeup portal as its name does
         # not start with 'waeup.'
-        class NonSIRPRole(grok.Role):
+        class NonKOFARole(grok.Role):
             grok.name('nonwaeup.testrole')
             grok.title('Role not suitable for waeup')
             grok.permissions('waeup.Public')
         grok.testing.grok_component('SomeRole', SomeRole)
-        grok.testing.grok_component('NonSIRPRole', NonSIRPRole)
+        grok.testing.grok_component('NonKOFARole', NonKOFARole)
         return
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_objecthistory.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_objecthistory.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_objecthistory.py	(revision 7811)
@@ -25,11 +25,11 @@
 from zope.security.management import newInteraction, endInteraction
 from zope.security.testing import Principal, Participation
-from waeup.sirp.app import University
-from waeup.sirp.interfaces import IObjectHistory, ISIRPObject
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
-from waeup.sirp.objecthistory import ObjectHistory
+from waeup.kofa.app import University
+from waeup.kofa.interfaces import IObjectHistory, IKOFAObject
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.objecthistory import ObjectHistory
 
 class SampleObject(grok.Model):
-    grok.implements(ISIRPObject)
+    grok.implements(IKOFAObject)
     pass
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_schoolgrades.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_schoolgrades.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_schoolgrades.py	(revision 7811)
@@ -2,6 +2,6 @@
 import unittest
 from zope.interface.verify import verifyObject, verifyClass
-from waeup.sirp.interfaces import IResultEntry, IResultEntryField
-from waeup.sirp.schoolgrades import ResultEntry, ResultEntryField
+from waeup.kofa.interfaces import IResultEntry, IResultEntryField
+from waeup.kofa.schoolgrades import ResultEntry, ResultEntryField
 
 class ResultEntryTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_smtp.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_smtp.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_smtp.py	(revision 7811)
@@ -27,10 +27,10 @@
 from zope.component.hooks import setSite
 from zope.sendmail.interfaces import IMailDelivery
-from waeup.sirp.app import University
-from waeup.sirp.interfaces import IMailService
-from waeup.sirp.smtp import (
+from waeup.kofa.app import University
+from waeup.kofa.interfaces import IMailService
+from waeup.kofa.smtp import (
     encode_header_item, encode_address, encode_body, FakeSMTPDelivery,
     send_mail)
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 #
@@ -328,5 +328,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP SIRP',
+            'Test Mail from WAeUP KOFA',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
@@ -345,5 +345,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP SIRP',
+            'Test Mail from WAeUP KOFA',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_doctests.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_doctests.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_doctests.py	(revision 7811)
@@ -16,7 +16,7 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Register doctests for waeup.sirp.
 """
-from waeup.sirp.testing import get_doctest_suite
+from waeup.kofa.testing import get_doctest_suite
 
 def test_suite():
@@ -16,7 +16,7 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Register doctests for waeup.sirp.
+"""Register doctests for waeup.kofa.
 """
Index: main/waeup.kofa/trunk/src/waeup/kofa/tests/test_waeup.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/tests/test_waeup.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/tests/test_waeup.py	(revision 7811)
@@ -17,5 +17,5 @@
 ##
 """
-Test setup for the waeup.sirp package.
+Test setup for the waeup.kofa package.
 """
 import grok
@@ -23,5 +23,5 @@
 import zope.component.eventtesting
 from zope.testing import renormalizing
-from waeup.sirp.testing import FunctionalLayer
+from waeup.kofa.testing import FunctionalLayer
 
 def setUpZope(test):
@@ -32,6 +32,6 @@
         ])
 
 # Register all tests in the waeup.sirp package
 test_suite = grok.testing.register_all_tests(
-    'waeup.sirp', checker=checker, usetup=setUpZope,
+    'waeup.kofa', checker=checker, usetup=setUpZope,
     layer=FunctionalLayer)
@@ -32,6 +32,6 @@
         ])
 
-# Register all tests in the waeup.sirp package
+# Register all tests in the waeup.kofa package
 test_suite = grok.testing.register_all_tests(
